#include "gfanapplication.h"
#include "field.h"
#include "division.h"
#include "printer.h"
#include "symmetry.h"

GFanApplication::FieldOption::FieldOption():
  SimpleOption("--mod2","Set the field to Z / 2Z.")
{
}

void GFanApplication::FieldOption::onOptionsParsed()
{
  if(getValue())
    Field::setField(Field::find("Zmod2Z"));
}


void GFanApplication::assertSymmetriesMatch(IntegerVectorList const &g, PolynomialSet &markedGroebnerBasis)
{
  int n=markedGroebnerBasis.numberOfVariablesInRing();
  for(IntegerVectorList::const_iterator i=g.begin();i!=g.end();i++)
    {
      if(i->size()!=n)
	{
	  fprintf(Stderr,"PERMUTATION ");
	  AsciiPrinter(Stderr).printVector(*i);
	  fprintf(Stderr," HAS WRONG LENGTH.\n");
	  assert(0);
	}
      if(!areIdealsEqual(markedGroebnerBasis,SymmetryGroup::permutePolynomialSet(markedGroebnerBasis,*i)))
	{
	  fprintf(Stderr,"PERMUTATION ");
	  AsciiPrinter(Stderr).printVector(*i);
	  fprintf(Stderr," DOES NOT KEEP THE IDEAL FIXED.\n");
	  assert(0);
	}
    }  
}
